# Generated by Django 3.0.14 on 2023-03-30 02:25

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bcmr', '0006_auto_20230330_0203'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='registry',
            options={'ordering': ('name', '-active'), 'verbose_name_plural': 'Registries'},
        ),
        migrations.AlterField(
            model_name='registry',
            name='active',
            field=models.BooleanField(default=True),
        ),
    ]
