# Generated by Django 3.0.14 on 2023-05-02 08:29

import django.contrib.postgres.fields.jsonb
from django.db import migrations, models
import django.utils.timezone


class Migration(migrations.Migration):

    dependencies = [
        ('bcmr', '0009_auto_20230331_0133'),
    ]

    operations = [
        migrations.CreateModel(
            name='TokenHistory',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('category', models.CharField(max_length=255)),
                ('token', django.contrib.postgres.fields.jsonb.JSONField(default=dict)),
                ('date', models.DateTimeField(default=django.utils.timezone.now)),
            ],
            options={
                'ordering': ('-date',),
            },
        ),
    ]
