# Generated by Django 3.0.14 on 2023-05-02 08:55

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('bcmr', '0011_auto_20230502_0839'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='tokenhistory',
            name='category',
        ),
    ]
