# Generated by Django 3.0.14 on 2023-03-31 01:31

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bcmr', '0007_auto_20230330_0225'),
    ]

    operations = [
        migrations.AlterField(
            model_name='token',
            name='description',
            field=models.TextField(blank=True, default=''),
        ),
    ]
