# Generated by Django 3.0.14 on 2023-05-02 08:39

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('bcmr', '0010_tokenhistory'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='tokenhistory',
            options={'ordering': ('-date',), 'verbose_name_plural': 'Token Histories'},
        ),
    ]
