# Generated by Django 3.1.6 on 2023-02-27 06:12

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bcmr', '0004_auto_20230214_0401'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='registry',
            name='owner',
        ),
        migrations.AddField(
            model_name='registry',
            name='active',
            field=models.BooleanField(default=False),
        ),
    ]
