# Generated by Django 3.0.14 on 2023-03-30 02:03

import django.contrib.postgres.fields.jsonb
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bcmr', '0005_auto_20230227_0612'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='token',
            options={'ordering': ('name', 'symbol', 'is_nft')},
        ),
        migrations.AddField(
            model_name='token',
            name='is_nft',
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name='token',
            name='nft_description',
            field=models.CharField(default='', max_length=255),
        ),
        migrations.AddField(
            model_name='token',
            name='nft_types',
            field=django.contrib.postgres.fields.jsonb.JSONField(default=dict),
        ),
        migrations.AlterField(
            model_name='token',
            name='description',
            field=models.CharField(blank=True, default='', max_length=255),
        ),
    ]
